translate.convert.sub2po

Package translate :: Package convert :: Module sub2po |
[hide private]
[frames] | no frames]

# Module sub2po

source code

convert subtitle files to Gettext PO localization files

Functions | [hide private]
convert_store(input_store, duplicatestyle="msgctxt") converts a subtitle file to a .po file... | source code
merge_store(template_store, input_store, blankmsgstr=False, duplicatestyle="msgctxt") converts two subtitle files to a .po file... | source code
convert_unit(input_unit, commenttype) Converts a subtitle unit to a .po unit. | source code
convertsub(input_file, output_file, template_file=None, pot=False, duplicatestyle="msgctxt") Reads in `input_file` using translate.subtitles, converts using sub2po, writes to `output_file` | source code
main(argv=None) | source code

Imports: sys, po, subtitles

Function Details | [hide private]

### convert_unit(input_unit, commenttype) | source code
Converts a subtitle unit to a .po unit. Returns None if empty or not for translation.